iiyo is Sinhala Prastha Pirulu Theravili, Thun theravili Sinhalen, Sinhala Random Name genarate

Developed by @dotLK from sasindu (c) 9:05 AM 3/4/2024

# Installation
```console

pip install iiyo

```
1.  >>> import iiyo
	
 //print(iiyo.sinhala.thun())

2. >>> print(prasthapirulu())
>>> 

3. # theravili_List
>>> print(theravili_List())
>>> 

>>>Press Enter Kye to Answer..
>>>  - 

4. thun_theravili
>>> print(thun_theravili())
>>>
>>>Press Enter Kye to Answer..
>>> 

//----Sinhala Random Name Genarater-------//

5 print(iiyo.random_names.maleaddress())

>>> print(queen())
>>> ['Avihinsaka uwathy','Nihada Mawatha ','Palu Niwahana']

>>> print(female_name())
>>> ['Anjalee Jayawardena']

>>> print(female_name_address())
>>> ['Anjalee Jayawardena','sadasiri Niwasa 12/A','Colombo 7']

>>> print(male_name())
>>> ['Chamara Dissanayake']

>>> print(male_name_address())
>>> ['Kasun samarawekrama','28/1 Pansala Para ,'Galle']

>>> ['Thilak jayasuriya','Cross Road','Colombo2']


Try :
print(iiyo.colombo.colombo(5)) // what is colombo 5
print(iiyo.english_names.get_full_name()) // get English names
print(iiyo.art)

------

Check out: https://www.youtube.com/@sasindu

You can use

* github.com/dotlk/iiyo